#include<bits/stdc++.h>

using namespace std;
#define int long long
typedef long double ld;
#define pb push_back

const ld EPS = 1e-17;

struct v2d {
    ld x, y;

    v2d() = default;

    v2d(ld x, ld y) : x(x), y(y) {}

    v2d operator-(v2d b) {
        return {x - b.x, y - b.y};
    }

    ld operator*(v2d b) {
        return x * b.x + y * b.y;
    }

    v2d operator*(ld b) {
        return {x * b, y * b};
    }

    v2d operator-() {
        return {-x, -y};
    }

    ld operator^(v2d b) {
        return x * b.y - b.x * y;
    }

    v2d operator+(v2d b) {
        return {x + b.x, y + b.y};
    }

    ld sq() {
        return x * x + y * y;
    }
};


bool is_parallel(v2d a1, v2d b1, v2d a2, v2d b2) {
    v2d v1 = b1 - a1;
    v2d v2 = b2 - a2;
    return abs(v1.x * v2.y - v2.x * v1.y) <= EPS;
}


v2d intersect_lines(v2d a, v2d b, v2d c, v2d d) {
    v2d v1 = b - a;
    v2d n1 = {v1.y, -v1.x};
    ld c1 = -n1 * a;
    v2d v2 = c - d;
    v2d n2 = {v2.y, -v2.x};
    ld c2 = -n2 * c;
    ld y = (-c2 * n1.x + c1 * n2.x) / (n1.x * n2.y - n2.x * n1.y);
    ld x = (-c2 * n1.y + c1 * n2.y) / (-n1.x * n2.y + n2.x * n1.y);
    return {x, y};
}

bool point_on_line(v2d p, v2d a, v2d b) {
    return abs((p - a) ^ (p - b)) <= EPS;
}


bool point_in_segment(v2d p, v2d a, v2d b) {
    if (!point_on_line(p, a, b)) return false;
    return (p - a) * (p - b) <= EPS;
}


v2d vtl(v2d p, v2d a, v2d b) {
    v2d v = (b - a);
    v2d n = {v.y, -v.x};
    return n * (((a - p) * n) / n.sq());
}

ld dist(v2d a, v2d b) {
    return sqrtl((a - b).sq());
}

ld dist_point_segment(v2d p, v2d a, v2d b) {
    v2d t = vtl(p, a, b);
    v2d lp = p + t;
    if (point_in_segment(lp, a, b)) return sqrtl(t.sq());
    return min(dist(p, a), dist(p, b));
}


ld dist_segments(v2d a, v2d b, v2d c, v2d d) {
    if (!is_parallel(a, b, c, d)) {
        v2d p = intersect_lines(a, b, c, d);
        if (point_in_segment(p, a, b) && point_in_segment(p, c, d)) return 0;
    }
    return min({
                       dist_point_segment(a, c, d),
                       dist_point_segment(b, c, d),
                       dist_point_segment(c, a, b),
                       dist_point_segment(d, a, b),
               });
}


void solve() {
    int m;
    cin >> m;
    vector<pair<v2d, v2d>> segs(m);
    for (int i = 0; i < m; i++) {
        cin >> segs[i].first.x >> segs[i].first.y >> segs[i].second.x >> segs[i].second.y;
    }
    int res = 0;
    for (int a = 0; a < m; a++) {
        for (int b = a + 1; b < m; b++) {
            for (int c = b + 1; c < m; c++) {
                {
                    int k = a, i = b, j = c;
                    if (+dist_segments(segs[i].first, segs[i].second, segs[j].first, segs[j].second) -
                        dist(segs[k].first, segs[k].second) <= EPS) {
                        res++;
                        continue;
                    }
                }

                {
                    int k = b, i = a, j = c;
                    if (+dist_segments(segs[i].first, segs[i].second, segs[j].first, segs[j].second) -
                        dist(segs[k].first, segs[k].second) <= EPS) {
                        res++;
                        continue;
                    }
                }

                {
                    int k = c, i = b, j = a;
                    if (+dist_segments(segs[i].first, segs[i].second, segs[j].first, segs[j].second) -
                        dist(segs[k].first, segs[k].second) <= EPS) {
                        res++;
                    }
                }
            }
        }
    }
    cout << res;
}

int32_t main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int tt = 1;
    //cin >> tt;
    while (tt--) {
        solve();
        //cout << '\n';
    }
}